@@ -19,6 +19,11 @@ class SuiteRequirements(Requirements):
 
         return exclusions.closed()
 
+    @property
+    def materialized_views(self):
+        """needed for sqlalchemy compat"""
+        return exclusions.closed()
+
     @property
     def unique_constraint_reflection(self):
         def doesnt_have_check_uq_constraints(config):
@@ -83,6 +88,13 @@ class SuiteRequirements(Requirements):
             "SQLAlchemy 1.4 or greater required",
         )
 
+    @property
+    def sqlalchemy_1x(self):
+        return exclusions.skip_if(
+            lambda config: not util.sqla_1x,
+            "SQLAlchemy 1.x test",
+        )
+
     @property
     def comments(self):
         return exclusions.only_if(
